@@ -37,7 +37,7 @@ from .delroom import subparser_delroom
 from .deluser import subparser_deluser
 from .deluser_jitsi import subparser_deluser_jitsi
 from .deploy import subparser_deploy
-from .maintainance import subparser_maintainance
+from .maintenance import subparser_maintenance
 from .rooms import subparser_rooms
 from .start import subparser_restart
 from .start import subparser_start
@@ -80,7 +80,7 @@ def setup_parser() -> argparse.ArgumentParser:
         subparser_deploy,
         subparser_start,
         subparser_restart,  # alias for start
-        subparser_maintainance,
+        subparser_maintenance,
         subparser_check,
         subparser_version,
     ]
